@@ -54,8 +54,8 @@ class ForwardContentProcessor(ContentProcessor):
         assert isinstance(content, ForwardContent), 'forward content error: %s' % content
         # call messenger to process it
         messenger = self.messenger
-        from ..messenger import Messenger
-        assert isinstance(messenger, Messenger)
+        # from ..messenger import Messenger
+        # assert isinstance(messenger, Messenger)
         secret = content.message
         secret = messenger.process_reliable_message(msg=secret)
         # check response
