@@ -54,23 +54,23 @@ class MessagePacker(Packer):
         return self.messenger.facebook
 
     def __is_waiting(self, identifier: ID) -> bool:
-        # broadcast ID doesn't contain meta or visa
-        if identifier.is_broadcast:
-            return False
         if identifier.is_group:
-            # if group is not broadcast ID, its meta should be exists
+            # checking group meta
             return self.facebook.meta(identifier=identifier) is None
-        # if user is not broadcast ID, its visa key should be exists
-        return self.facebook.public_key_for_encryption(identifier=identifier) is None
+        else:
+            # checking visa key
+            return self.facebook.public_key_for_encryption(identifier=identifier) is None
 
     def encrypt_message(self, msg: InstantMessage) -> Optional[SecureMessage]:
         receiver = msg.receiver
         group = msg.group
-        if self.__is_waiting(receiver) or (group is not None and self.__is_waiting(group)):
-            # NOTICE: the application will query visa automatically,
-            #         save this message in a queue waiting sender's visa response
-            self.messenger.suspend_message(msg=msg)
-            return None
+        if not (receiver.is_broadcast or (group is not None and group.is_broadcast)):
+            # this message is not a broadcast message
+            if self.__is_waiting(receiver) or (group is not None and self.__is_waiting(group)):
+                # NOTICE: the application will query visa automatically,
+                #         save this message in a queue waiting sender's visa response
+                self.messenger.suspend_message(msg=msg)
+                return None
         # make sure visa.key exists before encrypting message
         return super().encrypt_message(msg=msg)
 
